#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
'/usr/bin/ghc-pkg' 'unregister' '--force' '--global' 'interpolatedstring-perl6-1.0.2' "$@"
